@@ -22,6 +22,7 @@
  ********************************************************************************/
 
 
+#include <Rmath.h>
 extern "C"
 {
 #include "lh.h"
@@ -31,7 +32,6 @@ extern "C"
 #include "rand_pdf.h"
 #include "gen_covar.h"
 #include "rhelp.h"
-#include <Rmath.h>
 }
 #include "model.h"
 #include <stdlib.h>
@@ -75,7 +75,7 @@ Model::Model(Params* params, unsigned int d, double** rect, int Id, bool trace,
   if(parallel) { init_parallel_preds(); consumer_start(); }
   
   /* stuff to do with printing */
-  OUTFILE = mystdout;
+  OUTFILE = MYstdout;
   verb = 2;
   this->trace = trace;
 
@@ -244,6 +244,16 @@ void Model::rounds(Preds *preds, unsigned int B, unsigned int T, void *state)
     assert(((int)ceil(((double)(T-B))/preds->R)) == (int)preds->mult);
   }
 
+  /* TESTING TREE DISTANCE */
+  /* double **td1, **td2; int *tdp; double *th, *tad;
+  if(preds) {
+    td1 = new_zero_matrix(preds->nn, preds->nn);
+    td2 = new_zero_matrix(preds->nn, preds->nn);
+    th = new_zero_vector(preds->nn);
+    tad = new_zero_vector(preds->nn);
+    tdp = iseq(0, preds->nn);
+  } */
+
   /* for the leavesList function in the for loop below */
   unsigned int numLeaves = 1;
   
@@ -257,8 +267,8 @@ void Model::rounds(Preds *preds, unsigned int B, unsigned int T, void *state)
     if((r+1)%4 == 0) DrawInvTemp(state, r < (int)B);
 
     /* propose tree changes */
-    bool treemod = false;
-    if((r+1)%4 == 0) treemod = modify_tree(state);
+    /* bool treemod = false; */
+    if((r+1)%4 == 0) /* treemod = */ modify_tree(state);
     
     /* get leaves of the tree */
     Tree **leaves = t->leavesList(&numLeaves);
@@ -302,22 +312,25 @@ void Model::rounds(Preds *preds, unsigned int B, unsigned int T, void *state)
       /* keep track of MAP, and calculate importance sampling weight */
       double w = Posterior(true); /* must call Posterior for mapt */
       if(its->IT_ST_or_IS()) {
-	preds->w[index/preds->mult] = w;
-	preds->itemp[index/preds->mult] = its->Itemp();
+        preds->w[index/preds->mult] = w;
+        preds->itemp[index/preds->mult] = its->Itemp();
       }
 
       /* For random XX (eg sensitivity analysis), draw the predictive locations */
       if(preds->nm > 0){
-	sens_sample(preds->XX, preds->nn, preds->d, preds->bnds, preds->shape, 
-		    preds->mode, state); 
-	dupv(preds->M[index/preds->mult], preds->XX[0], preds->d * preds->nm);
-	normalize(preds->XX, preds->rect, preds->nn, preds->d, 1.0);
+        sens_sample(preds->XX, preds->nn, preds->d, preds->bnds, preds->shape, 
+          preds->mode, state); 
+        dupv(preds->M[index/preds->mult], preds->XX[0], preds->d * preds->nm);
+        normalize(preds->XX, preds->rect, preds->nn, preds->d, 1.0);
       }
 
+      /* TESTING TREE DISTANCE */
+      // t->Distance(preds->XX, tdp, preds->nn, td1, th, td2, tad);
+
       /* predict for each leaf */
       /* make sure to do this after calculation of preds->w[r], above */
       for(unsigned int i=0; i<numLeaves; i++)
-	predict_master(leaves[i], preds, index, state);
+        predict_master(leaves[i], preds, index, state);
       
       /* keeping track of the average number of partitions */
       double m = ((double)(r-B)) / preds->mult;
@@ -333,7 +346,7 @@ void Model::rounds(Preds *preds, unsigned int B, unsigned int T, void *state)
     free(leaves); 
 
     /* periodically check R for interrupts and flush console every second */
-    itime = my_r_process_events(itime);
+    itime = MY_r_process_events(itime);
   }
   
   /* send a full set of leaves out for prediction */
@@ -343,8 +356,21 @@ void Model::rounds(Preds *preds, unsigned int B, unsigned int T, void *state)
   if(parallel) wrap_up_predictions(); 
 
   /* normalize Ds2x, i.e., divide by the total (not within-partition) XX locs */
-  if(preds && preds->Ds2x) 
+  if(preds && preds->Ds2x)
     scalev(preds->Ds2x[0], preds->R * preds->nn, 1.0/preds->nn);
+
+  /* TESTING TREE DISTANCE */
+  /* if(preds) {
+    scalev(*td1, preds->nn * preds->nn, 1.0/preds->R);
+    matrix_to_file("node_dist.txt", td1, preds->nn, preds->nn);
+    scalev(*td2, preds->nn * preds->nn, 1.0/preds->R);
+    matrix_to_file("nodeabs_dist.txt", td2, preds->nn, preds->nn);
+    delete_matrix(td1);
+    delete_matrix(td2);
+    free(tdp);
+    free(th);
+    free(tad);
+  } */
 }
 
 
@@ -612,10 +638,10 @@ void Model::cut_branch(void *state)
   unsigned int k = (unsigned int) sample_seq(0,len,state);
   if(k == len) { 
     if(verb >= 1) 
-      myprintf(OUTFILE, "tree unchanged (no branches removed)\n");
+      MYprintf(OUTFILE, "tree unchanged (no branches removed)\n");
   } else {
     if(verb >= 1) 
-      myprintf(OUTFILE, "removed %d leaves from the tree\n", nodes[k]->numLeaves());
+      MYprintf(OUTFILE, "removed %d leaves from the tree\n", nodes[k]->numLeaves());
     nodes[k]->cut_branch();
   }
   free(nodes);
@@ -633,10 +659,10 @@ void Model::cut_root(void)
 { 
   if(t->isLeaf()) {
     if(verb >= 1)
-      myprintf(OUTFILE, "removed 0 leaves from the tree\n");
+      MYprintf(OUTFILE, "removed 0 leaves from the tree\n");
   } else {
     if(verb >= 1) 
-      myprintf(OUTFILE, "removed %d leaves from the tree\n", t->numLeaves());
+      MYprintf(OUTFILE, "removed %d leaves from the tree\n", t->numLeaves());
   }
   t->cut_branch();
 }
@@ -694,11 +720,11 @@ void Model::new_data(double **X, unsigned int n, unsigned int d, double* Z, doub
 
 void Model::PrintTreeStats(FILE* outfile)
 {
-  if(grow_try > 0) myprintf(outfile, "Grow: %.4g%c, ", 100* (double)grow/grow_try, '%');
-  if(prune_try > 0) myprintf(outfile, "Prune: %.4g%c, ", 100* (double)prune/prune_try, '%');
-  if(change_try > 0) myprintf(outfile, "Change: %.4g%c, ", 100* (double)change/change_try, '%');
-  if(swap_try > 0) myprintf(outfile, "Swap: %.4g%c", 100* (double)swap/swap_try, '%');
-  if(grow_try > 0) myprintf(outfile, "\n");
+  if(grow_try > 0) MYprintf(outfile, "Grow: %.4g%c, ", 100* (double)grow/grow_try, '%');
+  if(prune_try > 0) MYprintf(outfile, "Prune: %.4g%c, ", 100* (double)prune/prune_try, '%');
+  if(change_try > 0) MYprintf(outfile, "Change: %.4g%c, ", 100* (double)change/change_try, '%');
+  if(swap_try > 0) MYprintf(outfile, "Swap: %.4g%c", 100* (double)swap/swap_try, '%');
+  if(grow_try > 0) MYprintf(outfile, "\n");
 }
 
 
@@ -805,47 +831,47 @@ void Model::PrintState(unsigned int r, unsigned int numLeaves, Tree** leaves)
   /* print round information */
 #ifdef PARALLEL
   if(num_produced - num_consumed > 0)
-    myprintf(OUTFILE, "(r,l)=(%d,%d) ", r, num_produced - num_consumed);
-  else myprintf(OUTFILE, "r=%d ", r);
+    MYprintf(OUTFILE, "(r,l)=(%d,%d) ", r, num_produced - num_consumed);
+  else MYprintf(OUTFILE, "r=%d ", r);
 #else
-  myprintf(OUTFILE, "r=%d ", r);
+  MYprintf(OUTFILE, "r=%d ", r);
 #endif
   
   /* this is here so that the progress meter in SampleMap doesn't need to print
      the same tree information each time */
   if(numLeaves > 0) {
 
-    // myprintf(OUTFILE, " d=");
+    // MYprintf(OUTFILE, " d=");
 
     /* print the (correllation) state (d-values and maybe nugget values) */
     for(unsigned int i=0; i<numLeaves; i++) {
       char *state = leaves[i]->State(i);
-      myprintf(OUTFILE, "%s", state);
-      if(i != numLeaves-1) myprintf(OUTFILE, " ");
+      MYprintf(OUTFILE, "%s", state);
+      if(i != numLeaves-1) MYprintf(OUTFILE, " ");
       free(state);
     }
     
     /* a delimeter */
-    myprintf(OUTFILE, "; ");
+    MYprintf(OUTFILE, "; ");
     
     /* print maximum posterior prob tree height */
     Tree *maxt = maxPosteriors();
-    if(maxt) myprintf(OUTFILE, "mh=%d ", maxt->Height());
+    if(maxt) MYprintf(OUTFILE, "mh=%d ", maxt->Height());
     
     /* print partition sizes */
-    if(numLeaves > 1) myprintf(OUTFILE, "n=(");
-    else myprintf(OUTFILE, "n=");
+    if(numLeaves > 1) MYprintf(OUTFILE, "n=(");
+    else MYprintf(OUTFILE, "n=");
     for(unsigned int i=0; i<numLeaves-1; i++)
-      myprintf(OUTFILE, "%d,", leaves[i]->getN());
-    if(numLeaves > 1) myprintf(OUTFILE, "%d)", leaves[numLeaves-1]->getN());
-    else myprintf(OUTFILE, "%d", leaves[numLeaves-1]->getN());
+      MYprintf(OUTFILE, "%d,", leaves[i]->getN());
+    if(numLeaves > 1) MYprintf(OUTFILE, "%d)", leaves[numLeaves-1]->getN());
+    else MYprintf(OUTFILE, "%d", leaves[numLeaves-1]->getN());
     
   }
 
   /* cap off the printing */
-  if(its->Numit() > 1) myprintf(OUTFILE, " k=%g", its->Itemp());
-  myprintf(OUTFILE, "\n");
-  myflush(OUTFILE);  
+  if(its->Numit() > 1) MYprintf(OUTFILE, " k=%g", its->Itemp());
+  MYprintf(OUTFILE, "\n");
+  MYflush(OUTFILE);  
 }
 
 
@@ -1071,7 +1097,7 @@ void Model::predict_consumer(void)
 /*
  * predict_consumer_c:
  * 
- * a dummy c-style function that calls the
+ * a dumMY c-style function that calls the
  * consumer function from the Model class
  */
 
@@ -1148,8 +1174,8 @@ void Model::wrap_up_predictions(void)
       tlen = tlist->Len();
       diff = num_produced - num_consumed;
       if(verb >= 1) {
-        myprintf(OUTFILE, "waiting for (%d, %d) predictions\n", tlen, diff); 
-        myflush(OUTFILE); 
+        MYprintf(OUTFILE, "waiting for (%d, %d) predictions\n", tlen, diff); 
+        MYflush(OUTFILE); 
       }
     }
     pthread_mutex_unlock(l_mut);
@@ -1354,11 +1380,11 @@ FILE* Model::OpenFile(const char *prefix, const char *type)
 void Model::PrintTree(FILE* outfile)
 {
   assert(outfile);
-  myprintf(outfile, "rows var n dev yval splits.cutleft splits.cutright ");
+  MYprintf(outfile, "rows var n dev yval splits.cutleft splits.cutright ");
 
   /* the following are for printing a higher precision val, and base model
      parameters for reconstructing trees later */
-  myprintf(outfile, "val ");
+  MYprintf(outfile, "val ");
   TraceNames(outfile, true);
   this->t->PrintTree(outfile, iface_rect, NORMSCALE, 1);
 }
@@ -1399,7 +1425,7 @@ void Model::DrawInvTemp(void* state, bool burnin)
   //double diff_post = pnew - p;
   double diff_lik =  llnew - ll;
 
-  //myprintf(mystderr, "diff=%g\n", diff_post-diff_lik);
+  //MYprintf(MYstderr, "diff=%g\n", diff_post-diff_lik);
   //assert(diff_post == diff_lik);
 
   /* add in the priors for the itemp (weights) */
@@ -1460,14 +1486,14 @@ double Model::Posterior(bool record)
     /* allocate the trace files for printing posteriors*/   
     if(!POSTTRACEFILE) {
       POSTTRACEFILE = OpenFile("trace", "post");
-      myprintf(POSTTRACEFILE, "height leaves lpost itemp tlpost w\n");
+      MYprintf(POSTTRACEFILE, "height leaves lpost itemp tlpost w\n");
     }
 
     /* write a line to the file recording the trace of the posteriors */
-    myprintf(POSTTRACEFILE, "%d %d %15f %15f %15f %15f\n", 
+    MYprintf(POSTTRACEFILE, "%d %d %15f %15f %15f %15f\n", 
 	     t->Height(), t->numLeaves(), full_post, its->Itemp(), 
 	     full_post_temp, w);
-    myflush(POSTTRACEFILE);
+    MYflush(POSTTRACEFILE);
   }
 
   return w;
@@ -1489,7 +1515,7 @@ void Model::PrintPosteriors(void)
   /* open a file to write the posterior information to */
   sprintf(filestr, "tree_m%d_posts.out", Id);
   FILE *postsfile = fopen(filestr, "w");
-  myprintf(postsfile, "height lpost ");
+  MYprintf(postsfile, "height lpost ");
   PriorTraceNames(postsfile, true);
 
   /* unsigned int t_minpart, t_splitmin;
@@ -1504,11 +1530,11 @@ void Model::PrintPosteriors(void)
     FILE *treefile = fopen(filestr, "w");
 
     /* add maptree-relevant headers */
-    myprintf(treefile, "rows var n dev yval splits.cutleft splits.cutright ");
+    MYprintf(treefile, "rows var n dev yval splits.cutleft splits.cutright ");
 
     /* the following are for printing a higher precision val, and base model
      parameters for reconstructing trees later */
-    myprintf(treefile, "val ");
+    MYprintf(treefile, "val ");
 
     /* add parameter trace relevant headers */
     TraceNames(treefile, true);
@@ -1519,7 +1545,7 @@ void Model::PrintPosteriors(void)
 
     /* add information about height and posteriors to file */
     assert(i+1 == posteriors->trees[i]->Height());
-    myprintf(postsfile, "%d %g ", posteriors->trees[i]->Height(), posteriors->posts[i]);
+    MYprintf(postsfile, "%d %g ", posteriors->trees[i]->Height(), posteriors->posts[i]);
     
     /* add prior parameter trace information to the posts file */
     unsigned int tlen;
@@ -1614,7 +1640,7 @@ void Model::Linburn(unsigned int B, void *state)
 {
   double gam = Linear();
   //if(gam) {
-    if(verb > 0) myprintf(OUTFILE, "\nlinear model init:\n");
+    if(verb > 0) MYprintf(OUTFILE, "\nlinear model init:\n");
     rounds(NULL, B, B, state);
     ResetLinear(gam);
   //}
@@ -1629,7 +1655,7 @@ void Model::Linburn(unsigned int B, void *state)
 
 void Model::Burnin(unsigned int B, void *state)
 {
-  if(verb >= 1 && B>0) myprintf(OUTFILE, "\nburn in:\n");
+  if(verb >= 1 && B>0) MYprintf(OUTFILE, "\nburn in:\n");
   rounds(NULL, B, B, state);
 }
 
@@ -1646,7 +1672,7 @@ void Model::StochApprox(unsigned int B, void *state)
 {
   if(!its->DoStochApprox()) return;
   if(verb >= 1 && B>0) 
-    myprintf(OUTFILE, "\nburn in: [with stoch approx (c0,n0)=(%g,%g)]\n",
+    MYprintf(OUTFILE, "\nburn in: [with stoch approx (c0,n0)=(%g,%g)]\n",
 	     its->C0(), its->N0());
 
   /* do the rounds of stochastic approximation */
@@ -1671,9 +1697,9 @@ void Model::Sample(Preds *preds, unsigned int R, void *state)
   if(R == 0) return;
 
   if(verb >= 1 && R>0) {
-    myprintf(OUTFILE, "\nSampling @ nn=%d pred locs:", preds->nn);
-    if(trace) myprintf(OUTFILE, " [with traces]");
-    myprintf(OUTFILE, "\n");
+    MYprintf(OUTFILE, "\nSampling @ nn=%d pred locs:", preds->nn);
+    if(trace) MYprintf(OUTFILE, " [with traces]");
+    MYprintf(OUTFILE, "\n");
   }
 		       
   rounds(preds, 0, R, state);
@@ -1692,7 +1718,7 @@ void Model::Predict(Preds *preds, unsigned int R, void *state)
   if(R == 0) return;
   assert(preds);
 
-  if(verb >=1) myprintf(OUTFILE, "\nKriging @ nn=%d predictive locs:\n", preds->nn);
+  if(verb >=1) MYprintf(OUTFILE, "\nKriging @ nn=%d predictive locs:\n", preds->nn);
 
   /* get leaves of the tree */
   unsigned int numLeaves;
@@ -1718,7 +1744,7 @@ void Model::Predict(Preds *preds, unsigned int R, void *state)
 	sens_sample(preds->XX, preds->nn, preds->d, preds->bnds, preds->shape, 
 		    preds->mode, state); 
 	dupv(preds->M[r/preds->mult], preds->XX[0], preds->d * preds->nm);
-	//printf("xx: \n"); printMatrix(preds->XX, preds->nn, preds->d, mystdout);
+	//printf("xx: \n"); printMatrix(preds->XX, preds->nn, preds->d, MYstdout);
 	normalize(preds->XX, preds->rect, preds->nn, preds->d, 1.0);
       }
 
@@ -1735,7 +1761,7 @@ void Model::Predict(Preds *preds, unsigned int R, void *state)
     }
 
     /* periodically check R for interrupts and flush console every second */
-    itime = my_r_process_events(itime);
+    itime = MY_r_process_events(itime);
   }
 
   /* clean up */
@@ -1780,10 +1806,10 @@ void Model::TraceNames(FILE * outfile, bool full)
   unsigned int len;
   char **trace_names = t->TraceNames(&len, full);
   for(unsigned int i=0; i<len; i++) {
-    myprintf(outfile, "%s ", trace_names[i]);
+    MYprintf(outfile, "%s ", trace_names[i]);
     free(trace_names[i]);
   }
-  myprintf(outfile, "\n");
+  MYprintf(outfile, "\n");
   free(trace_names);
 }
 
@@ -1802,10 +1828,10 @@ void Model::PriorTraceNames(FILE * outfile, bool full)
   unsigned int len;
   char **trace_names = base_prior->TraceNames(&len, full);
   for(unsigned int i=0; i<len; i++) {
-    myprintf(outfile, "%s ", trace_names[i]);
+    MYprintf(outfile, "%s ", trace_names[i]);
     free(trace_names[i]);
   }
-  myprintf(outfile, "\n");
+  MYprintf(outfile, "\n");
   free(trace_names);
 }
 
@@ -1833,13 +1859,13 @@ void Model::Trace(Tree *leaf, unsigned int index)
   if(!XXTRACEFILE) {
     /* trace of GP parameters for each XX input location */
     XXTRACEFILE = OpenFile("trace", "XX");
-    myprintf(XXTRACEFILE, "ppi index ");
+    MYprintf(XXTRACEFILE, "ppi index ");
     TraceNames(XXTRACEFILE, false);
   }
 
   /* actual printing of trace for a tree leaf */
   leaf->Trace(index, XXTRACEFILE);
-  myflush(XXTRACEFILE);
+  MYflush(XXTRACEFILE);
 
   /* unlock */
 #ifdef PARALLEL
